Input

pub struct Input {
    pub id: Option<FHIRUri>,
    pub persist: Option<FHIRBoolean>,
    pub graph: Option<FHIRUri>,
}

Fields

id: Option<FHIRUri>

Identifies the composition to use. This can either be a simple id, which identifies a composition, or it can be a full URL, which identifies a composition on another server.

Notes:

  • GET [base]/Composition/[id]/$document is identical in meaning to GET [base]/Composition/$document?id=[id]
  • the id parameter SHALL NOT be used if the operation is requested on a particular composition (e.g. GET [base]/Composition/[id]/$document?id=[id] is not allowed)
  • Servers are not required to support generating documents on Compositions located on another server
persist: Option<FHIRBoolean>

Whether to store the document at the bundle end-point (/Bundle) or not once it is generated. Value = true or false (default is for the server to decide). If the document is stored, it’s location can be inferred from the Bundle.id, but it SHOULD be provided explicitly in the HTTP Location header in the response

graph: Option<FHIRUri>

Canonical reference to a GraphDefinition. If a URL is provided, it is the canonical reference to a GraphDefinition that it controls what resources are to be added to the bundle when building the document. The GraphDefinition can also specify profiles that apply to the various resources